# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..gtract import gtractCoregBvalues


def test_gtractCoregBvalues_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        debugLevel=dict(argstr="--debugLevel %d",),
        eddyCurrentCorrection=dict(argstr="--eddyCurrentCorrection ",),
        environ=dict(nohash=True, usedefault=True,),
        fixedVolume=dict(argstr="--fixedVolume %s", extensions=None,),
        fixedVolumeIndex=dict(argstr="--fixedVolumeIndex %d",),
        maximumStepSize=dict(argstr="--maximumStepSize %f",),
        minimumStepSize=dict(argstr="--minimumStepSize %f",),
        movingVolume=dict(argstr="--movingVolume %s", extensions=None,),
        numberOfIterations=dict(argstr="--numberOfIterations %d",),
        numberOfSpatialSamples=dict(argstr="--numberOfSpatialSamples %d",),
        numberOfThreads=dict(argstr="--numberOfThreads %d",),
        outputTransform=dict(argstr="--outputTransform %s", hash_files=False,),
        outputVolume=dict(argstr="--outputVolume %s", hash_files=False,),
        registerB0Only=dict(argstr="--registerB0Only ",),
        relaxationFactor=dict(argstr="--relaxationFactor %f",),
        samplingPercentage=dict(argstr="--samplingPercentage %f",),
        spatialScale=dict(argstr="--spatialScale %f",),
    )
    inputs = gtractCoregBvalues.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_gtractCoregBvalues_outputs():
    output_map = dict(
        outputTransform=dict(extensions=None,), outputVolume=dict(extensions=None,),
    )
    outputs = gtractCoregBvalues.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..odf import SFPeaks


def test_SFPeaks_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        density=dict(argstr="-density %d", units="NA",),
        environ=dict(nohash=True, usedefault=True,),
        in_file=dict(argstr="-inputfile %s", extensions=None, mandatory=True,),
        inputmodel=dict(argstr="-inputmodel %s", mandatory=True,),
        mepointset=dict(argstr="-mepointset %d", units="NA",),
        noconsistencycheck=dict(argstr="-noconsistencycheck",),
        numpds=dict(argstr="-numpds %d", units="NA",),
        order=dict(argstr="-order %d", units="NA",),
        out_file=dict(argstr="> %s", extensions=None, genfile=True, position=-1,),
        pdthresh=dict(argstr="-pdthresh %f", units="NA",),
        pointset=dict(argstr="-pointset %d", units="NA",),
        rbfpointset=dict(argstr="-rbfpointset %d", units="NA",),
        scheme_file=dict(argstr="%s", extensions=None,),
        searchradius=dict(argstr="-searchradius %f", units="NA",),
        stdsfrommean=dict(argstr="-stdsfrommean %f", units="NA",),
    )
    inputs = SFPeaks.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_SFPeaks_outputs():
    output_map = dict(peaks=dict(extensions=None,),)
    outputs = SFPeaks.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..utils import ComposeMultiTransform


def test_ComposeMultiTransform_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        dimension=dict(argstr="%d", position=0, usedefault=True,),
        environ=dict(nohash=True, usedefault=True,),
        num_threads=dict(nohash=True, usedefault=True,),
        output_transform=dict(
            argstr="%s",
            extensions=None,
            keep_extension=True,
            name_source=["transforms"],
            name_template="%s_composed",
            position=1,
        ),
        reference_image=dict(argstr="%s", extensions=None, position=2,),
        transforms=dict(argstr="%s", mandatory=True, position=3,),
    )
    inputs = ComposeMultiTransform.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_ComposeMultiTransform_outputs():
    output_map = dict(output_transform=dict(extensions=None,),)
    outputs = ComposeMultiTransform.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..preprocess import Fim


def test_Fim_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        fim_thr=dict(argstr="-fim_thr %f", position=3,),
        ideal_file=dict(
            argstr="-ideal_file %s", extensions=None, mandatory=True, position=2,
        ),
        in_file=dict(
            argstr="-input %s",
            copyfile=False,
            extensions=None,
            mandatory=True,
            position=1,
        ),
        num_threads=dict(nohash=True, usedefault=True,),
        out=dict(argstr="-out %s", position=4,),
        out_file=dict(
            argstr="-bucket %s",
            extensions=None,
            name_source="in_file",
            name_template="%s_fim",
        ),
        outputtype=dict(),
    )
    inputs = Fim.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_Fim_outputs():
    output_map = dict(out_file=dict(extensions=None,),)
    outputs = Fim.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..specialized import FiducialRegistration


def test_FiducialRegistration_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        fixedLandmarks=dict(argstr="--fixedLandmarks %s...",),
        movingLandmarks=dict(argstr="--movingLandmarks %s...",),
        outputMessage=dict(argstr="--outputMessage %s",),
        rms=dict(argstr="--rms %f",),
        saveTransform=dict(argstr="--saveTransform %s", hash_files=False,),
        transformType=dict(argstr="--transformType %s",),
    )
    inputs = FiducialRegistration.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_FiducialRegistration_outputs():
    output_map = dict(saveTransform=dict(extensions=None,),)
    outputs = FiducialRegistration.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..utils import MRIMarchingCubes


def test_MRIMarchingCubes_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        connectivity_value=dict(argstr="%d", position=-1, usedefault=True,),
        environ=dict(nohash=True, usedefault=True,),
        in_file=dict(argstr="%s", extensions=None, mandatory=True, position=1,),
        label_value=dict(argstr="%d", mandatory=True, position=2,),
        out_file=dict(argstr="./%s", extensions=None, genfile=True, position=-2,),
        subjects_dir=dict(),
    )
    inputs = MRIMarchingCubes.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_MRIMarchingCubes_outputs():
    output_map = dict(surface=dict(extensions=None,),)
    outputs = MRIMarchingCubes.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..utils import SmoothTessellation


def test_SmoothTessellation_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        curvature_averaging_iterations=dict(argstr="-a %d",),
        disable_estimates=dict(argstr="-nw",),
        environ=dict(nohash=True, usedefault=True,),
        gaussian_curvature_norm_steps=dict(argstr="%d",),
        gaussian_curvature_smoothing_steps=dict(argstr=" %d",),
        in_file=dict(
            argstr="%s", copyfile=True, extensions=None, mandatory=True, position=-2,
        ),
        normalize_area=dict(argstr="-area",),
        out_area_file=dict(argstr="-b %s", extensions=None,),
        out_curvature_file=dict(argstr="-c %s", extensions=None,),
        out_file=dict(argstr="%s", extensions=None, genfile=True, position=-1,),
        seed=dict(argstr="-seed %d",),
        smoothing_iterations=dict(argstr="-n %d",),
        snapshot_writing_iterations=dict(argstr="-w %d",),
        subjects_dir=dict(),
        use_gaussian_curvature_smoothing=dict(argstr="-g",),
        use_momentum=dict(argstr="-m",),
    )
    inputs = SmoothTessellation.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_SmoothTessellation_outputs():
    output_map = dict(surface=dict(extensions=None,),)
    outputs = SmoothTessellation.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..preprocess import ROIStats


def test_ROIStats_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        debug=dict(argstr="-debug",),
        environ=dict(nohash=True, usedefault=True,),
        format1D=dict(argstr="-1Dformat", xor=["format1DR"],),
        format1DR=dict(argstr="-1DRformat", xor=["format1D"],),
        in_file=dict(argstr="%s", extensions=None, mandatory=True, position=-2,),
        mask=dict(
            argstr="-mask %s",
            deprecated="1.1.4",
            extensions=None,
            new_name="mask_file",
            position=3,
        ),
        mask_f2short=dict(argstr="-mask_f2short",),
        mask_file=dict(argstr="-mask %s", extensions=None,),
        nobriklab=dict(argstr="-nobriklab",),
        nomeanout=dict(argstr="-nomeanout",),
        num_roi=dict(argstr="-numroi %s",),
        out_file=dict(
            argstr="> %s",
            extensions=None,
            keep_extension=False,
            name_source="in_file",
            name_template="%s_roistat.1D",
            position=-1,
        ),
        quiet=dict(argstr="-quiet",),
        roisel=dict(argstr="-roisel %s", extensions=None,),
        stat=dict(argstr="%s...",),
        zerofill=dict(argstr="-zerofill %s", requires=["num_roi"],),
    )
    inputs = ROIStats.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_ROIStats_outputs():
    output_map = dict(out_file=dict(extensions=None,),)
    outputs = ROIStats.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..preprocess import MRIConvert


def test_MRIConvert_inputs():
    input_map = dict(
        apply_inv_transform=dict(
            argstr="--apply_inverse_transform %s", extensions=None,
        ),
        apply_transform=dict(argstr="--apply_transform %s", extensions=None,),
        args=dict(argstr="%s",),
        ascii=dict(argstr="--ascii",),
        autoalign_matrix=dict(argstr="--autoalign %s", extensions=None,),
        color_file=dict(argstr="--color_file %s", extensions=None,),
        conform=dict(argstr="--conform",),
        conform_min=dict(argstr="--conform_min",),
        conform_size=dict(argstr="--conform_size %s",),
        crop_center=dict(argstr="--crop %d %d %d",),
        crop_gdf=dict(argstr="--crop_gdf",),
        crop_size=dict(argstr="--cropsize %d %d %d",),
        cut_ends=dict(argstr="--cutends %d",),
        cw256=dict(argstr="--cw256",),
        devolve_transform=dict(argstr="--devolvexfm %s",),
        drop_n=dict(argstr="--ndrop %d",),
        environ=dict(nohash=True, usedefault=True,),
        fill_parcellation=dict(argstr="--fill_parcellation",),
        force_ras=dict(argstr="--force_ras_good",),
        frame=dict(argstr="--frame %d",),
        frame_subsample=dict(argstr="--fsubsample %d %d %d",),
        fwhm=dict(argstr="--fwhm %f",),
        in_center=dict(argstr="--in_center %s",),
        in_file=dict(
            argstr="--input_volume %s", extensions=None, mandatory=True, position=-2,
        ),
        in_i_dir=dict(argstr="--in_i_direction %f %f %f",),
        in_i_size=dict(argstr="--in_i_size %d",),
        in_info=dict(argstr="--in_info",),
        in_j_dir=dict(argstr="--in_j_direction %f %f %f",),
        in_j_size=dict(argstr="--in_j_size %d",),
        in_k_dir=dict(argstr="--in_k_direction %f %f %f",),
        in_k_size=dict(argstr="--in_k_size %d",),
        in_like=dict(argstr="--in_like %s", extensions=None,),
        in_matrix=dict(argstr="--in_matrix",),
        in_orientation=dict(argstr="--in_orientation %s",),
        in_scale=dict(argstr="--scale %f",),
        in_stats=dict(argstr="--in_stats",),
        in_type=dict(argstr="--in_type %s",),
        invert_contrast=dict(argstr="--invert_contrast %f",),
        midframe=dict(argstr="--mid-frame",),
        no_change=dict(argstr="--nochange",),
        no_scale=dict(argstr="--no_scale 1",),
        no_translate=dict(argstr="--no_translate",),
        no_write=dict(argstr="--no_write",),
        out_center=dict(argstr="--out_center %f %f %f",),
        out_datatype=dict(argstr="--out_data_type %s",),
        out_file=dict(
            argstr="--output_volume %s", extensions=None, genfile=True, position=-1,
        ),
        out_i_count=dict(argstr="--out_i_count %d",),
        out_i_dir=dict(argstr="--out_i_direction %f %f %f",),
        out_i_size=dict(argstr="--out_i_size %d",),
        out_info=dict(argstr="--out_info",),
        out_j_count=dict(argstr="--out_j_count %d",),
        out_j_dir=dict(argstr="--out_j_direction %f %f %f",),
        out_j_size=dict(argstr="--out_j_size %d",),
        out_k_count=dict(argstr="--out_k_count %d",),
        out_k_dir=dict(argstr="--out_k_direction %f %f %f",),
        out_k_size=dict(argstr="--out_k_size %d",),
        out_matrix=dict(argstr="--out_matrix",),
        out_orientation=dict(argstr="--out_orientation %s",),
        out_scale=dict(argstr="--out-scale %d",),
        out_stats=dict(argstr="--out_stats",),
        out_type=dict(argstr="--out_type %s",),
        parse_only=dict(argstr="--parse_only",),
        read_only=dict(argstr="--read_only",),
        reorder=dict(argstr="--reorder %d %d %d",),
        resample_type=dict(argstr="--resample_type %s",),
        reslice_like=dict(argstr="--reslice_like %s", extensions=None,),
        sdcm_list=dict(argstr="--sdcmlist %s", extensions=None,),
        skip_n=dict(argstr="--nskip %d",),
        slice_bias=dict(argstr="--slice-bias %f",),
        slice_crop=dict(argstr="--slice-crop %d %d",),
        slice_reverse=dict(argstr="--slice-reverse",),
        smooth_parcellation=dict(argstr="--smooth_parcellation",),
        sphinx=dict(argstr="--sphinx",),
        split=dict(argstr="--split",),
        status_file=dict(argstr="--status %s", extensions=None,),
        subject_name=dict(argstr="--subject_name %s",),
        subjects_dir=dict(),
        te=dict(argstr="-te %d",),
        template_info=dict(argstr="--template_info",),
        template_type=dict(argstr="--template_type %s",),
        ti=dict(argstr="-ti %d",),
        tr=dict(argstr="-tr %d",),
        unwarp_gradient=dict(argstr="--unwarp_gradient_nonlinearity",),
        vox_size=dict(argstr="-voxsize %f %f %f",),
        zero_ge_z_offset=dict(argstr="--zero_ge_z_offset",),
        zero_outlines=dict(argstr="--zero_outlines",),
    )
    inputs = MRIConvert.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_MRIConvert_outputs():
    output_map = dict(out_file=dict(),)
    outputs = MRIConvert.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..dti import DTMetric


def test_DTMetric_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        data_header=dict(argstr="-header %s", extensions=None,),
        eigen_data=dict(argstr="-inputfile %s", extensions=None, mandatory=True,),
        environ=dict(nohash=True, usedefault=True,),
        inputdatatype=dict(argstr="-inputdatatype %s", usedefault=True,),
        metric=dict(argstr="-stat %s", mandatory=True,),
        outputdatatype=dict(argstr="-outputdatatype %s", usedefault=True,),
        outputfile=dict(argstr="-outputfile %s", extensions=None, genfile=True,),
    )
    inputs = DTMetric.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_DTMetric_outputs():
    output_map = dict(metric_stats=dict(extensions=None,),)
    outputs = DTMetric.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..utils import Zeropad


def test_Zeropad_inputs():
    input_map = dict(
        A=dict(argstr="-A %i", xor=["master"],),
        AP=dict(argstr="-AP %i", xor=["master"],),
        I=dict(argstr="-I %i", xor=["master"],),
        IS=dict(argstr="-IS %i", xor=["master"],),
        L=dict(argstr="-L %i", xor=["master"],),
        P=dict(argstr="-P %i", xor=["master"],),
        R=dict(argstr="-R %i", xor=["master"],),
        RL=dict(argstr="-RL %i", xor=["master"],),
        S=dict(argstr="-S %i", xor=["master"],),
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        in_files=dict(
            argstr="%s", copyfile=False, extensions=None, mandatory=True, position=-1,
        ),
        master=dict(
            argstr="-master %s",
            extensions=None,
            xor=["I", "S", "A", "P", "L", "R", "z", "RL", "AP", "IS", "mm"],
        ),
        mm=dict(argstr="-mm", xor=["master"],),
        num_threads=dict(nohash=True, usedefault=True,),
        out_file=dict(argstr="-prefix %s", extensions=None, name_template="zeropad",),
        outputtype=dict(),
        z=dict(argstr="-z %i", xor=["master"],),
    )
    inputs = Zeropad.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_Zeropad_outputs():
    output_map = dict(out_file=dict(extensions=None,),)
    outputs = Zeropad.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..resampling import ApplyTransforms


def test_ApplyTransforms_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        default_value=dict(argstr="--default-value %g", usedefault=True,),
        dimension=dict(argstr="--dimensionality %d",),
        environ=dict(nohash=True, usedefault=True,),
        float=dict(argstr="--float %d", usedefault=True,),
        input_image=dict(argstr="--input %s", extensions=None, mandatory=True,),
        input_image_type=dict(argstr="--input-image-type %d",),
        interpolation=dict(argstr="%s", usedefault=True,),
        interpolation_parameters=dict(),
        invert_transform_flags=dict(),
        num_threads=dict(nohash=True, usedefault=True,),
        out_postfix=dict(usedefault=True,),
        output_image=dict(argstr="--output %s", genfile=True, hash_files=False,),
        print_out_composite_warp_file=dict(requires=["output_image"],),
        reference_image=dict(
            argstr="--reference-image %s", extensions=None, mandatory=True,
        ),
        transforms=dict(argstr="%s", mandatory=True,),
    )
    inputs = ApplyTransforms.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_ApplyTransforms_outputs():
    output_map = dict(output_image=dict(extensions=None,),)
    outputs = ApplyTransforms.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..stats import UnaryStats


def test_UnaryStats_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        in_file=dict(argstr="%s", extensions=None, mandatory=True, position=2,),
        larger_voxel=dict(argstr="-t %f", position=-3,),
        mask_file=dict(argstr="-m %s", extensions=None, position=-2,),
        operation=dict(argstr="-%s", mandatory=True, position=4,),
    )
    inputs = UnaryStats.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_UnaryStats_outputs():
    output_map = dict(output=dict(),)
    outputs = UnaryStats.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..preprocess import BlurInMask


def test_BlurInMask_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        automask=dict(argstr="-automask",),
        environ=dict(nohash=True, usedefault=True,),
        float_out=dict(argstr="-float",),
        fwhm=dict(argstr="-FWHM %f", mandatory=True,),
        in_file=dict(
            argstr="-input %s",
            copyfile=False,
            extensions=None,
            mandatory=True,
            position=1,
        ),
        mask=dict(argstr="-mask %s", extensions=None,),
        multimask=dict(argstr="-Mmask %s", extensions=None,),
        num_threads=dict(nohash=True, usedefault=True,),
        options=dict(argstr="%s", position=2,),
        out_file=dict(
            argstr="-prefix %s",
            extensions=None,
            name_source="in_file",
            name_template="%s_blur",
            position=-1,
        ),
        outputtype=dict(),
        preserve=dict(argstr="-preserve",),
    )
    inputs = BlurInMask.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_BlurInMask_outputs():
    output_map = dict(out_file=dict(extensions=None,),)
    outputs = BlurInMask.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..preprocess import TShift


def test_TShift_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        ignore=dict(argstr="-ignore %s",),
        in_file=dict(
            argstr="%s", copyfile=False, extensions=None, mandatory=True, position=-1,
        ),
        interp=dict(argstr="-%s",),
        num_threads=dict(nohash=True, usedefault=True,),
        out_file=dict(
            argstr="-prefix %s",
            extensions=None,
            name_source="in_file",
            name_template="%s_tshift",
        ),
        outputtype=dict(),
        rlt=dict(argstr="-rlt",),
        rltplus=dict(argstr="-rlt+",),
        slice_encoding_direction=dict(usedefault=True,),
        slice_timing=dict(argstr="-tpattern @%s", xor=["tpattern"],),
        tpattern=dict(argstr="-tpattern %s", xor=["slice_timing"],),
        tr=dict(argstr="-TR %s",),
        tslice=dict(argstr="-slice %s", xor=["tzero"],),
        tzero=dict(argstr="-tzero %s", xor=["tslice"],),
    )
    inputs = TShift.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_TShift_outputs():
    output_map = dict(
        out_file=dict(extensions=None,), timing_file=dict(extensions=None,),
    )
    outputs = TShift.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..fix import Classifier


def test_Classifier_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        artifacts_list_file=dict(extensions=None,),
        environ=dict(nohash=True, usedefault=True,),
        mel_ica=dict(argstr="%s", copyfile=False, position=1,),
        thresh=dict(argstr="%d", mandatory=True, position=-1,),
        trained_wts_file=dict(
            argstr="%s", copyfile=False, extensions=None, mandatory=True, position=2,
        ),
    )
    inputs = Classifier.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_Classifier_outputs():
    output_map = dict(artifacts_list_file=dict(extensions=None,),)
    outputs = Classifier.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..utils import ParcellationStats


def test_ParcellationStats_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        aseg=dict(extensions=None, mandatory=True,),
        brainmask=dict(extensions=None, mandatory=True,),
        copy_inputs=dict(),
        cortex_label=dict(extensions=None,),
        environ=dict(nohash=True, usedefault=True,),
        hemisphere=dict(argstr="%s", mandatory=True, position=-2,),
        in_annotation=dict(argstr="-a %s", extensions=None, xor=["in_label"],),
        in_cortex=dict(argstr="-cortex %s", extensions=None,),
        in_label=dict(
            argstr="-l %s", extensions=None, xor=["in_annotatoin", "out_color"],
        ),
        lh_pial=dict(extensions=None, mandatory=True,),
        lh_white=dict(extensions=None, mandatory=True,),
        mgz=dict(argstr="-mgz",),
        out_color=dict(
            argstr="-c %s", extensions=None, genfile=True, xor=["in_label"],
        ),
        out_table=dict(
            argstr="-f %s", extensions=None, genfile=True, requires=["tabular_output"],
        ),
        rh_pial=dict(extensions=None, mandatory=True,),
        rh_white=dict(extensions=None, mandatory=True,),
        ribbon=dict(extensions=None, mandatory=True,),
        subject_id=dict(argstr="%s", mandatory=True, position=-3, usedefault=True,),
        subjects_dir=dict(),
        surface=dict(argstr="%s", position=-1,),
        tabular_output=dict(argstr="-b",),
        th3=dict(argstr="-th3", requires=["cortex_label"],),
        thickness=dict(extensions=None, mandatory=True,),
        transform=dict(extensions=None, mandatory=True,),
        wm=dict(extensions=None, mandatory=True,),
    )
    inputs = ParcellationStats.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_ParcellationStats_outputs():
    output_map = dict(
        out_color=dict(extensions=None,), out_table=dict(extensions=None,),
    )
    outputs = ParcellationStats.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..developer import RandomVol


def test_RandomVol_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        inField=dict(argstr="--inField %s",),
        inLambda=dict(argstr="--inLambda %f",),
        inMaximum=dict(argstr="--inMaximum %d",),
        inMinimum=dict(argstr="--inMinimum %d",),
        inSize=dict(argstr="--inSize %d",),
        inSize2=dict(argstr="--inSize2 %d",),
        inSize3=dict(argstr="--inSize3 %d",),
        inSize4=dict(argstr="--inSize4 %d",),
        inStandard=dict(argstr="--inStandard %d",),
        null=dict(argstr="--null %s",),
        outRand1=dict(argstr="--outRand1 %s", hash_files=False,),
        xDefaultMem=dict(argstr="-xDefaultMem %d",),
        xMaxProcess=dict(argstr="-xMaxProcess %d", usedefault=True,),
        xPrefExt=dict(argstr="--xPrefExt %s",),
    )
    inputs = RandomVol.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_RandomVol_outputs():
    output_map = dict(outRand1=dict(extensions=None,),)
    outputs = RandomVol.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..segmentation import BRAINSTalairachMask


def test_BRAINSTalairachMask_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        expand=dict(argstr="--expand ",),
        hemisphereMode=dict(argstr="--hemisphereMode %s",),
        inputVolume=dict(argstr="--inputVolume %s", extensions=None,),
        outputVolume=dict(argstr="--outputVolume %s", hash_files=False,),
        talairachBox=dict(argstr="--talairachBox %s", extensions=None,),
        talairachParameters=dict(argstr="--talairachParameters %s", extensions=None,),
    )
    inputs = BRAINSTalairachMask.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_BRAINSTalairachMask_outputs():
    output_map = dict(outputVolume=dict(extensions=None,),)
    outputs = BRAINSTalairachMask.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..model import Binarize


def test_Binarize_inputs():
    input_map = dict(
        abs=dict(argstr="--abs",),
        args=dict(argstr="%s",),
        bin_col_num=dict(argstr="--bincol",),
        bin_val=dict(argstr="--binval %d",),
        bin_val_not=dict(argstr="--binvalnot %d",),
        binary_file=dict(argstr="--o %s", extensions=None, genfile=True,),
        count_file=dict(argstr="--count %s",),
        dilate=dict(argstr="--dilate %d",),
        environ=dict(nohash=True, usedefault=True,),
        erode=dict(argstr="--erode  %d",),
        erode2d=dict(argstr="--erode2d %d",),
        frame_no=dict(argstr="--frame %s",),
        in_file=dict(argstr="--i %s", copyfile=False, extensions=None, mandatory=True,),
        invert=dict(argstr="--inv",),
        mask_file=dict(argstr="--mask maskvol", extensions=None,),
        mask_thresh=dict(argstr="--mask-thresh %f",),
        match=dict(argstr="--match %d...",),
        max=dict(argstr="--max %f", xor=["wm_ven_csf"],),
        merge_file=dict(argstr="--merge %s", extensions=None,),
        min=dict(argstr="--min %f", xor=["wm_ven_csf"],),
        out_type=dict(argstr="",),
        rmax=dict(argstr="--rmax %f",),
        rmin=dict(argstr="--rmin %f",),
        subjects_dir=dict(),
        ventricles=dict(argstr="--ventricles",),
        wm=dict(argstr="--wm",),
        wm_ven_csf=dict(argstr="--wm+vcsf", xor=["min", "max"],),
        zero_edges=dict(argstr="--zero-edges",),
        zero_slice_edge=dict(argstr="--zero-slice-edges",),
    )
    inputs = Binarize.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_Binarize_outputs():
    output_map = dict(
        binary_file=dict(extensions=None,), count_file=dict(extensions=None,),
    )
    outputs = Binarize.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value
